==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/ToolChain/install_13_CPU_STM32F2xx.sh <==
#!/bin/bash

#
#  Install script for Microcontroller STM32 F1xx 
#  with ARM Cortex M3 core + Std Peripherals Library for STM32F1xx.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="200_cpu_stm32f2xx"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOURUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Documentation ]; then #{
    InstallDir=`pwd`
    dir ../../Documentation/uC
    dir ../../Documentation/uC
    cd ../../Documentation/uC
    
    dir CortexM3
    cd CortexM3
    DocDir=`pwd`
    
    GetFails=""
    #getFile http://www.eecs.umich.edu/~prabal/teaching/eecs373-f11/readings/                            ARMv7-M_ARM.pdf ARMv7-M_Architecture_Reference_Manual.pdf                                   || ERROR="1"
    dir STM      #{
    cd STM
    #getFile http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/REFERENCE_MANUAL/   CD00240193.pdf STM32_RM0038_Advanced_ARM-based_32bit_MCUs.pdf                               || ERROR="1"

    cd ..
    cd "$InstallDir"
#}

    if [ "$GetFails" == "" ]; then
      echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    else
      echo "$0 - ERROR: Cannot retrieve $GetFails"
    fi
  fi #}
  if [ ! -e OK.Install ];       then #{
    if [ ! -e OK.Packages ]; then #{
      touch OK.Packages
    fi #}
    if [ -e OK.Packages ]; then #{
      Error=""
      
      Archive="stm32f2xx_stdperiph_lib.zip"
      # getFile http://www.st.com/stonline/products/support/micro/files/ $Archive
      getFile http://www.st.com/internet/com/SOFTWARE_RESOURCES/SW_COMPONENT/FIRMWARE/ $Archive

      if [ ! -e $Archive ]; then
        Error="Cannot download $Archive!"
      fi
      unZIP STM32F10x_StdPeriph_Lib $Archive || mv -f $Archive ${Archive}_bad
      rm current 2>/dev/null

      # find name of only directory
      LibraryDir=`find ./  -maxdepth 1 -mindepth 1 -type d -print`
      ln -sv $LibraryDir current
      cd current

      dir ../../../Documentation/STM
      mv *.chm ../../../Documentation/STM/
    
      cd ..
    
      if [ "$Error" == "" ]; then
        touch OK.Install
      else
        echo "$0 - ERROR: $ERROR!"
        exit 10
      fi
    fi #}
  fi #}
  if [   -e OK.Install ];       then #{
    Architecture="stm32f2xx"
    Name="${INSTALLPATH}"
    LibPrefix="250_stm_std_peripherals_"
    LibName="${LibPrefix}f2xx"
    createExtensionMakefileHead ${Name} #{          create makefile for cpu
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$File 

COMPILE_OPTS += -DEXTENSION_$Name

ARM_CPU      = arm7tdmi
TARGET       = -mcpu=cortex-m3 -mthumb
TARGET_ARCHITECTURE_CM3 = 1
TARGET_ARCHITECTURE_STM32 = 1
TARGET_ARCHITECTURE_PREFIX = STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_STM32

# architecture specific support code
INCLUDE_DIRS += -Iadditionals/common/stm32/
vpath %.c additionals/common/stm32/

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{     create activate for cpu
    createActivateScriptHead $File $0 "CPU STM32F2xx"
    cat <<END_OF_ACTIVATE >>$File #{

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.200_cpu_*
    
# create links into extensions.active/
createLink ../extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
    
# activate corresponding std_peripheral_library
activate.250_CPAL_STM32F2xx_StdPeriph_Driver.sh QUIET

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $Name
    #}

    if [ "0" == "1" ]; then #{ DISABLED: std_peripheral_library_f2xx
    createExtensionMakefileHead ${LibName} #{       create makefile for std_peripheral_library
    File="../extensions/makefile.${LibName}" 
    cat <<END_OF_MAKEFILE >>$File 

COMPILE_OPTS += -DEXTENSION_250_stm_std_peripherals=1

INCLUDE_DIRS += -I additionals/250_stm_std_peripherals/STM32F10x_StdPeriph_Driver/inc/ \\
                -I additionals/250_stm_std_peripherals/CMSIS/CM3/DeviceSupport/ST/STM32F2xx/ \\
                -I additionals/250_stm_std_peripherals/CMSIS/CM3/CoreSupport/

vpath %.c additionals/250_stm_std_peripherals/STM32F2xx_StdPeriph_Driver/src/ \\
          additionals/250_stm_std_peripherals/CMSIS/CM3/DeviceSupport/ST/STM32F2xx/

vpath %.s additionals/250_stm_std_peripherals/CMSIS/CM3/DeviceSupport/ST/STM32F2xx/startup/gcc_ride7

END_OF_MAKEFILE
    createExtensionMakefileTail ${LibName} #}
    File="../extensions/activate.${LibName}.sh" #{  create activate for std_peripheral_library
    createActivateScriptHead $File $0 "Standard Peripheral Library for CPU STM32F2xx"
    cat <<END_OF_ACTIVATE >>$File #{

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${LibPrefix}*

OldPWD="\`pwd\`"
cd "\$Dir_Extensions/"
rm 2>/dev/null makefile.${LibPrefix}_*
rm 2>/dev/null activate.${LibPrefix}_*
ln -s  $Architecture/* .
cd "\$OldPWD"

# create links into extensions.active/
createLink \$Dir_Extensions/makefile.$LibName \$Dir_ExtensionsActive/makefile.$LibName '' QUIET

# we must create a new link in additionals
if [ -d "\$Dir_Additionals" ]; then
  cd "\$Dir_Additionals"
  rm 2>/dev/null 250_stm_std_peripherals
  ln -sv 250_STM32F2xx_StdPeriph_Driver  \$Dir_Additionals/250_stm_std_peripherals
  cd ..
else
  echo "\$0 - ERROR: Cannot find directory additionals/ (\`pwd\`/\$Dir_Additionals)!"
fi

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $LibName
    #}

    BaseName=$LibName
    dir ../extensions/$Architecture

    # create one activate-script per feature
    for Feature in `find current/Libraries/STM32F2xx_StdPeriph_Driver/src/ -name "${Architecture}_*" -execdir echo -n "{} " \;` ; do #{
      Feature=`perl -e "print substr('$Feature', 12, -2);"`

      FeatureName="${LibPrefix}_${Feature}"
      #echo "FeatureName='$FeatureName'" #D
      createExtensionMakefileHead ${FeatureName} ../extensions/${Architecture}/ #{
      cat <<END_OF_MAKEFILE >>$MakeFile # set by createExtensionMakefileHead() 

MAIN_OBJS += ${Architecture}_${Feature}.o

END_OF_MAKEFILE
      createExtensionMakefileTail ${FeatureName} ../extensions/${Architecture}/ #}
      File="../extensions/${Architecture}/activate.${FeatureName}.sh" #{
      createActivateScriptHead $File $0 "append C-source from standar peripheral library for compilation: ${FeatureName}.c"
      cat <<END_OF_ACTIVATE >>$File #{

# add createL.inks for each link required for this extension
createLink ../extensions/makefile.$FeatureName \$Dir_ExtensionsActive/makefile.$FeatureName '' QUIET

END_OF_ACTIVATE
#}
      createActivateScriptTail $File $FeatureName
      #}
    done #}
    fi #}std_peripheral_library_f2xx
    
    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.39.tar.bz: ToolChain_STM32_1.0.39/ToolChain/install_13_CPU_STM32F2xx.sh <==
#!/bin/bash

#
#  Install script for Microcontroller STM32 F1xx 
#  with ARM Cortex M3 core + Std Peripherals Library for STM32F1xx.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="200_cpu_stm32f2xx"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOURUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Documentation ]; then #{
    InstallDir=`pwd`
    dir ../../Documentation/uC
    dir ../../Documentation/uC
    cd ../../Documentation/uC
    
    dir CortexM3
    cd CortexM3
    DocDir=`pwd`
    
    GetFails=""
    #getFile http://www.eecs.umich.edu/~prabal/teaching/eecs373-f11/readings/                            ARMv7-M_ARM.pdf ARMv7-M_Architecture_Reference_Manual.pdf                                   || ERROR="1"
    dir STM      #{
    cd STM
    #getFile http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/REFERENCE_MANUAL/   CD00240193.pdf STM32_RM0038_Advanced_ARM-based_32bit_MCUs.pdf                               || ERROR="1"

    cd ..
    cd "$InstallDir"
#}

    if [ "$GetFails" == "" ]; then
      echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    else
      echo "$0 - ERROR: Cannot retrieve $GetFails"
    fi
  fi #}
  if [ ! -e OK.Install ];       then #{
    if [ ! -e OK.Packages ]; then #{
      touch OK.Packages
    fi #}
    if [ -e OK.Packages ]; then #{
      Error=""
      
      Archive="stm32f2xx_stdperiph_lib.zip"
      # getFile http://www.st.com/stonline/products/support/micro/files/ $Archive
      getFile http://www.st.com/internet/com/SOFTWARE_RESOURCES/SW_COMPONENT/FIRMWARE/ $Archive

      if [ ! -e $Archive ]; then
        Error="Cannot download $Archive!"
      fi
      unZIP STM32F10x_StdPeriph_Lib $Archive || mv -f $Archive ${Archive}_bad
      rm current 2>/dev/null

      # find name of only directory
      LibraryDir=`find ./  -maxdepth 1 -mindepth 1 -type d -print`
      ln -sv $LibraryDir current
      cd current

      dir ../../../Documentation/STM
      mv *.chm ../../../Documentation/STM/
    
      cd ..
    
      if [ "$Error" == "" ]; then
        touch OK.Install
      else
        echo "$0 - ERROR: $ERROR!"
        exit 10
      fi
    fi #}
  fi #}
  if [   -e OK.Install ];       then #{
    Architecture="stm32f2xx"
    Name="${INSTALLPATH}"
    LibPrefix="250_stm_std_peripherals_"
    LibName="${LibPrefix}f2xx"
    createExtensionMakefileHead ${Name} #{          create makefile for cpu
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$File 

COMPILE_OPTS += -DEXTENSION_${Name}=1

ARM_CPU     =arm7tdmi
TARGET      =-mcpu=cortex-m3 -mthumb
TARGET_ARCHITECTURE_CM3=1
TARGET_ARCHITECTURE_STM32=1
TARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_STM32

# architecture specific support code
INCLUDE_DIRS += -Iadditionals/common/stm32/
vpath %.c additionals/common/stm32/

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{     create activate for cpu
    createActivateScriptHead $File $0 "CPU STM32F2xx"
    cat <<END_OF_ACTIVATE >>$File #{

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.200_cpu_*
    
# create links into extensions.active/
createLink ../extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
    
# activate corresponding std_peripheral_library
activate.250_CPAL_STM32F2xx_StdPeriph_Driver.sh QUIET

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $Name
    #}

    if [ "0" == "1" ]; then #{ DISABLED: std_peripheral_library_f2xx
    createExtensionMakefileHead ${LibName} #{       create makefile for std_peripheral_library
    File="../extensions/makefile.${LibName}" 
    cat <<END_OF_MAKEFILE >>$File 

COMPILE_OPTS += -DEXTENSION_250_stm_std_peripherals=1

INCLUDE_DIRS += -I additionals/250_stm_std_peripherals/STM32F10x_StdPeriph_Driver/inc/ \\
                -I additionals/250_stm_std_peripherals/CMSIS/CM3/DeviceSupport/ST/STM32F2xx/ \\
                -I additionals/250_stm_std_peripherals/CMSIS/CM3/CoreSupport/

vpath %.c additionals/250_stm_std_peripherals/STM32F2xx_StdPeriph_Driver/src/ \\
          additionals/250_stm_std_peripherals/CMSIS/CM3/DeviceSupport/ST/STM32F2xx/

vpath %.s additionals/250_stm_std_peripherals/CMSIS/CM3/DeviceSupport/ST/STM32F2xx/startup/gcc_ride7

END_OF_MAKEFILE
    createExtensionMakefileTail ${LibName} #}
    File="../extensions/activate.${LibName}.sh" #{  create activate for std_peripheral_library
    createActivateScriptHead $File $0 "Standard Peripheral Library for CPU STM32F2xx"
    cat <<END_OF_ACTIVATE >>$File #{

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${LibPrefix}*

OldPWD="\`pwd\`"
cd "\$Dir_Extensions/"
rm 2>/dev/null makefile.${LibPrefix}_*
rm 2>/dev/null activate.${LibPrefix}_*
ln -s  $Architecture/* .
cd "\$OldPWD"

# create links into extensions.active/
createLink \$Dir_Extensions/makefile.$LibName \$Dir_ExtensionsActive/makefile.$LibName '' QUIET

# we must create a new link in additionals
if [ -d "\$Dir_Additionals" ]; then
  cd "\$Dir_Additionals"
  rm 2>/dev/null 250_stm_std_peripherals
  ln -sv 250_STM32F2xx_StdPeriph_Driver  \$Dir_Additionals/250_stm_std_peripherals
  cd ..
else
  echo "\$0 - ERROR: Cannot find directory additionals/ (\`pwd\`/\$Dir_Additionals)!"
fi

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $LibName
    #}

    BaseName=$LibName
    dir ../extensions/$Architecture

    # create one activate-script per feature
    for Feature in `find current/Libraries/STM32F2xx_StdPeriph_Driver/src/ -name "${Architecture}_*" -execdir echo -n "{} " \;` ; do #{
      Feature=`perl -e "print substr('$Feature', 12, -2);"`

      FeatureName="${LibPrefix}_${Feature}"
      #echo "FeatureName='$FeatureName'" #D
      createExtensionMakefileHead ${FeatureName} ../extensions/${Architecture}/ #{
      cat <<END_OF_MAKEFILE >>$MakeFile # set by createExtensionMakefileHead() 

MAIN_OBJS += ${Architecture}_${Feature}.o

END_OF_MAKEFILE
      createExtensionMakefileTail ${FeatureName} ../extensions/${Architecture}/ #}
      File="../extensions/${Architecture}/activate.${FeatureName}.sh" #{
      createActivateScriptHead $File $0 "append C-source from standar peripheral library for compilation: ${FeatureName}.c"
      cat <<END_OF_ACTIVATE >>$File #{

# add createL.inks for each link required for this extension
createLink ../extensions/makefile.$FeatureName \$Dir_ExtensionsActive/makefile.$FeatureName '' QUIET

END_OF_ACTIVATE
#}
      createActivateScriptTail $File $FeatureName
      #}
    done #}
    fi #}std_peripheral_library_f2xx
    
    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
